@@ -1,5 +1,6 @@
 sexsm <- function(data,h=10,w=NULL,init=c("mean","naive"),cost=c("mar","msr","mae","mse"),
-                  init.opt=c(TRUE,FALSE),outplot=c(FALSE,TRUE),opt.on=c(FALSE,TRUE)){
+                  init.opt=c(TRUE,FALSE),outplot=c(FALSE,TRUE),opt.on=c(FALSE,TRUE),
+                  na.rm=c(FALSE,TRUE)){
 # Simple Exponential Smoothing
 #
 # Inputs:
@@ -19,6 +20,7 @@ sexsm <- function(data,h=10,w=NULL,init=c("mean","naive"),cost=c("mar","msr","ma
 #   outplot     If TRUE a plot of the forecast is provided.
 #   opt.on      This is meant to use only by the optimisation function. When opt.on is 
 #               TRUE then no checks on inputs are performed. 
+#   na.rm       A logical value indicating whether NA values should be remove using the method.
 #
 # Outputs:
 #   model       Type of model fitted.
@@ -48,7 +50,14 @@ sexsm <- function(data,h=10,w=NULL,init=c("mean","naive"),cost=c("mar","msr","ma
   if (!is.numeric(init)){
     init <- init[1]
   } 
-  
+
+  # Prepare data
+  if (class(data)=="data.frame"){
+    data <- data[[1]]
+  }
+  if (na.rm == TRUE){
+    data <- data[!is.na(data)]
+  }  
   n <- length(data)
   
   # Initialise
